==> fparser_0.0.16.orig.tar.xz: fparser-0.0.16/src/fparser/two/tests/fortran2008/test_deferred_coshape_spec_r510.py <==
# Copyright (c) 2020 Science and Technology Facilities Council

# All rights reserved.

# Modifications made as part of the fparser project are distributed
# under the following license:

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:

# 1. Redistributions of source code must retain the above copyright
# notice, this list of conditions and the following disclaimer.

# 2. Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution.

# 3. Neither the name of the copyright holder nor the names of its
# contributors may be used to endorse or promote products derived from
# this software without specific prior written permission.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

'''Test Fortran 2008 rule R510

    deferred-coshape-spec is :

'''

import pytest
from fparser.two.Fortran2008 import Deferred_Coshape_Spec
from fparser.two import Fortran2003


@pytest.mark.usefixtures("f2008_create")
def test_deferred_coshape_spec():
    '''Test parsing of deferred_coshape_spec.'''
    obj = Deferred_Coshape_Spec(':')
    assert isinstance(obj, Deferred_Coshape_Spec), repr(obj)
    assert str(obj) == ':'


@pytest.mark.usefixtures("f2008_create")
@pytest.mark.parametrize('attr', ['', ' :', ': ', '  : ', '::', '5'])
def test_invalid_deferred_coshape_spec(attr):
    '''Test that invalid deferred_coshape_spec raise exception.'''
    with pytest.raises(Fortran2003.NoMatchError):
        _ = Deferred_Coshape_Spec(attr)

==> fparser_0.1.4.orig.tar.xz: fparser-0.1.4/src/fparser/two/tests/fortran2008/test_deferred_coshape_spec_r510.py <==
# Copyright (c) 2020 Science and Technology Facilities Council

# All rights reserved.

# Modifications made as part of the fparser project are distributed
# under the following license:

# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:

# 1. Redistributions of source code must retain the above copyright
# notice, this list of conditions and the following disclaimer.

# 2. Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution.

# 3. Neither the name of the copyright holder nor the names of its
# contributors may be used to endorse or promote products derived from
# this software without specific prior written permission.

# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

"""Test Fortran 2008 rule R510

    deferred-coshape-spec is :

"""

import pytest
from fparser.two.Fortran2008 import Deferred_Coshape_Spec
from fparser.two import Fortran2003


@pytest.mark.usefixtures("f2008_create")
def test_deferred_coshape_spec():
    """Test parsing of deferred_coshape_spec."""
    obj = Deferred_Coshape_Spec(":")
    assert isinstance(obj, Deferred_Coshape_Spec), repr(obj)
    assert str(obj) == ":"


@pytest.mark.usefixtures("f2008_create")
@pytest.mark.parametrize("attr", ["", " :", ": ", "  : ", "::", "5"])
def test_invalid_deferred_coshape_spec(attr):
    """Test that invalid deferred_coshape_spec raise exception."""
    with pytest.raises(Fortran2003.NoMatchError):
        _ = Deferred_Coshape_Spec(attr)
